@@ -13,7 +13,7 @@ using Eigen::MatrixXi;
 using Eigen::VectorXd;
 using Eigen::VectorXi;
 
-void translationSSA_full(int* riblocations, double* kelong, double* t_array, int Nt, double kbind, double kcompl, int* SSA_intensity, int N, int FRAP, int Inhibitor, double inhibit_time, int seed, double* SSA_ribtimes, int* watched_ribs, int ribtimesize, int cNt, int* col_result, double* col_t, int* col_x, int colNp, int* x0, int r_footprint, int* SSA_probe, int Ncolor, int* flags, double kon, double koff, double* k_probe,int* probe_loc,int* n_probes, int rib_max)
+void translationSSA_full(int* riblocations, double* kelong, double* t_array, int Nt, double kbind, double kcompl, int* SSA_intensity, int N, int FRAP, int Inhibitor, double inhibit_time, double inhibit_time_stop, int seed, double* SSA_ribtimes, int* watched_ribs, int ribtimesize, int cNt, int* col_result, double* col_t, int* col_x, int colNp, int* x0, int r_footprint, int* SSA_probe, int Ncolor, int* flags, double kon, double koff, double* k_probe,int* probe_loc,int* n_probes, int rib_max)
 {
     // Declare the variables
 	
@@ -317,7 +317,7 @@ void translationSSA_full(int* riblocations, double* kelong, double* t_array, int
 		// wipe all probes if FRAP
 		if (FRAP_pres) {
 			//std::cout << "--------n_probes=" << n_probes << "--------" << std::endl;
-			if ((t >= inhibit_time) && (t < inhibit_time + 20)) {
+			if ((t >= inhibit_time) && (t < inhibit_time_stop)) {
 				
 				for (int j = 0; j < Ncolor; j++) {
 					for (int i = 0; i < NR; i++) {
